.. _Sphere class:

The Sphere class
----------------

.. currentmodule:: rockverse.region

.. autoclass:: Sphere

   .. rubric:: Attributes

   .. autoattribute:: p
   .. autoattribute:: r
   .. autoattribute:: region

   .. rubric:: Methods

   .. automethod:: contains_point
